%bcond_with malcontent

%global major_version %%(echo %version | cut -d . -f 1)

Summary:        Utilities to configure the GNOME desktop
Name:           gnome-control-center
Version:        44.4
Release:        4%{?dist}
License:        GPLv2+ and CC-BY-SA
URL:            https://gitlab.gnome.org/GNOME/gnome-control-center/
Source0:        https://download.gnome.org/sources/%{name}/%{major_version}/%{name}-%{version}.tar.xz

BuildRequires:  desktop-file-utils docbook-style-xsl libxslt gcc gettext meson pkgconfig(libwacom)
BuildRequires:  pkgconfig(accountsservice) pkgconfig(clutter-gtk-1.0) pkgconfig(colord) pkgconfig(colord-gtk4)
BuildRequires:  pkgconfig(cups) pkgconfig(gcr-base-3) pkgconfig(gdk-pixbuf-2.0) pkgconfig(gdk-wayland-3.0)
BuildRequires:  pkgconfig(gnome-desktop-4) pkgconfig(gio-2.0) pkgconfig(gnome-settings-daemon) pkgconfig(goa-1.0)
BuildRequires:  pkgconfig(goa-backend-1.0) pkgconfig(gsettings-desktop-schemas) pkgconfig(gsound) pkgconfig(gtk4)
BuildRequires:  pkgconfig(gudev-1.0) pkgconfig(ibus-1.0) pkgconfig(libadwaita-1) pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libnm) pkgconfig(libnma-gtk4) pkgconfig(libpulse) pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(libsecret-1) pkgconfig(libxml-2.0) pkgconfig(mm-glib)
BuildRequires:  pkgconfig(polkit-gobject-1) pkgconfig(pwquality) pkgconfig(smbclient) pkgconfig(udisks2)
BuildRequires:  pkgconfig(upower-glib) pkgconfig(x11) pkgconfig(xi) pkgconfig(gnome-bluetooth-3.0)
%if %{with malcontent}
BuildRequires:  pkgconfig(malcontent-0)
%endif

Requires: libadwaita glib2 gnome-desktop4 gnome-online-accounts gnome-settings-daemon
Requires: gsettings-desktop-schemas gtk4 upower gnome-bluetooth accountsservice
Requires: alsa-lib colord cups-pk-helper dbus glx-utils iso-codes
Requires: %{name}-filesystem = %{version}-%{release} /usr/bin/gkbd-keyboard-display
%if %{with malcontent}
Requires: malcontent
Recommends: malcontent-control
%endif

Recommends: bolt NetworkManager-wifi nm-connection-editor rygel
Recommends: gnome-color-manager gnome-remote-desktop switcheroo-control power-profiles-daemon

Provides: control-center = %{version}-%{release}

%description
This package contains configuration utilities for the GNOME desktop, which allow to configure accessibility options,
desktop fonts, keyboard and mouseproperties, sound setup, desktop theme and background, user interfaceproperties,
screen resolution, and other settings.

%package filesystem
Summary: GNOME Control Center directories
Provides: control-center-filesystem = %{version}-%{release}

BuildArch: noarch

%description filesystem
The GNOME control-center provides a number of extension points for applications. This package contains directories where
applications can install configuration files that are picked up by the control-center utilities.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%meson \
  -Ddocumentation=true \
%if %{with malcontent}
  -Dmalcontent=true \
%else
  -Dmalcontent=false \
%endif
  %{nil}
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_datadir}/gnome/wm-properties

rm -rf %{buildroot}%{_datadir}/gnome/autostart
rm -rf %{buildroot}%{_datadir}/gnome/cursor-fonts

%find_lang %{name} --all-name --with-gnome

%files -f %{name}.lang
%license COPYING
%doc NEWS README.md
%{_bindir}/gnome-control-center
%{_datadir}/applications/*.desktop
%{_datadir}/bash-completion/completions/gnome-control-center
%{_datadir}/dbus-1/services/org.gnome.Settings.SearchProvider.service
%{_datadir}/dbus-1/services/org.gnome.Settings.service
%{_datadir}/gettext/
%{_datadir}/glib-2.0/schemas/org.gnome.Settings.gschema.xml
%{_datadir}/gnome-control-center/keybindings/*.xml
%{_datadir}/gnome-control-center/pixmaps
%{_datadir}/gnome-shell/search-providers/org.gnome.Settings.search-provider.ini
%{_datadir}/icons/gnome-logo-text*.svg
%{_datadir}/icons/hicolor/*/*/*
%{_metainfodir}/org.gnome.Settings.appdata.xml
%{_datadir}/pixmaps/faces
%{_datadir}/pkgconfig/gnome-keybindings.pc
%{_datadir}/polkit-1/actions/org.gnome.controlcenter.*.policy
%{_datadir}/polkit-1/rules.d/gnome-control-center.rules
%{_datadir}/sounds/gnome/default/*/*.ogg
%{_libexecdir}/cc-remote-login-helper
%{_libexecdir}/gnome-control-center-goa-helper
%{_libexecdir}/gnome-control-center-search-provider
%{_libexecdir}/gnome-control-center-print-renderer
%{_datadir}/man/man1/gnome-control-center.1*

%files filesystem
%dir %{_datadir}/gnome-control-center
%dir %{_datadir}/gnome-control-center/keybindings
%dir %{_datadir}/gnome/wm-properties

%changelog
* Wed Oct 30 2024 Rebuild Robot <rebot@opencloudos.org> - 44.4-4
- [Type] other
- [DESC] Rebuilt for gtk4

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 44.4-3
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 44.4-2
- Rebuilt for loongarch release

* Tue Sep 26 2023 Xiaojie Chen <jackxjchen@tencent.com> - 44.4-1
- Upgrade to upstream version 44.4
- Disable parental control (through malcontent)

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-9
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 Wang Guodong <gordonwwang@tencent.com> - 43.1-8
- Rebuilt for udisks2 2.10.0

* Fri Aug 18 2023 cunshunxia <cunshunxia@tencent.com> - 43.1-7
- Rebuilt for upower 1.90.2

* Thu Aug 17 2023 cunshunxia <cunshunxia@tencent.com> - 43.1-6
- Rebuilt for samba 4.18.5

* Thu Jul 20 2023 cunshunxia <cunshunxia@tencent.com> - 43.1-5
- Rebuilt for samba 4.18.4

* Mon Jul 17 2023 cunshunxia <cunshunxia@tencent.com> - 43.1-4
- rebuild for ModemManager 1.20.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Dec 7 2022 Shuo Wang <abushwang@tencent.com> - 43.1-1
- initial build

